@@ -22,6 +22,7 @@
 #' @param doi a Zenodo DOI or concept DOI
 #' @param path the target directory where to download files
 #' @param files subset of filenames to restrain to download. If ignored, all files will be downloaded.
+#' @param sandbox Use the sandbox infrastructure. Default is \code{FALSE}
 #' @param logger a logger to print Zenodo API-related messages. The logger can be either NULL, 
 #' "INFO" (with minimum logs), or "DEBUG" (for complete curl http calls logs)
 #' @param quiet Logical (\code{FALSE} by default).
@@ -31,9 +32,9 @@
 #' 
 #' @export
 #' 
-download_zenodo = function(doi, path = ".", files = list(), logger = NULL, quiet = FALSE, ...){
+download_zenodo = function(doi, path = ".", files = list(), sandbox = FALSE, logger = NULL, quiet = FALSE, ...){
   #rec
-  rec = get_zenodo(doi = doi, logger = logger)
+  rec = get_zenodo(doi = doi, sandbox = sandbox, logger = logger)
   #download
   rec$downloadFiles(path = path, files = files, quiet = quiet, ...)
 }
